@@ -13,6 +13,13 @@
 #ifndef _WX_MSW_CHKCONF_H_
 #define _WX_MSW_CHKCONF_H_
 
+/* ensure that CPU parameter is specified (only nmake .vc makefile) */
+#ifdef _MSC_VER
+    #if defined(_WIN64) && defined(TARGET_CPU_COMPFLAG) && (TARGET_CPU_COMPFLAG == 0)
+        #error CPU must be defined
+    #endif
+#endif
+
 /* ensure that MSW-specific settings are defined */
 #ifndef wxUSE_ACTIVEX
 #    ifdef wxABORT_ON_CONFIG_ERROR
@@ -118,6 +125,14 @@
 #    endif
 #endif  /* wxUSE_UXTHEME */
 
+#ifndef wxUSE_WINSOCK2
+#    ifdef wxABORT_ON_CONFIG_ERROR
+#        error "wxUSE_WINSOCK2 must be defined."
+#    else
+#        define wxUSE_WINSOCK2 0
+#    endif
+#endif  /* wxUSE_WINSOCK2 */
+
 /*
  * Unfortunately we can't use compiler TLS support if the library can be used
  * inside a dynamically loaded DLL under Windows XP, as this can result in hard
@@ -147,8 +162,7 @@
  * All of the settings below require SEH support (__try/__catch) and can't work
  * without it.
  */
-#if !defined(_MSC_VER) && \
-    (!defined(__BORLANDC__) || __BORLANDC__ < 0x0550)
+#if !defined(_MSC_VER)
 #    undef wxUSE_ON_FATAL_EXCEPTION
 #    define wxUSE_ON_FATAL_EXCEPTION 0
 
@@ -167,14 +181,6 @@
 #   undef  wxUSE_DEBUG_NEW_ALWAYS
 #   define wxUSE_DEBUG_NEW_ALWAYS          0
 
-/* some Cygwin versions don't have wcslen */
-#   if defined(__CYGWIN__) || defined(__CYGWIN32__)
-#   if ! ((__GNUC__>2) ||((__GNUC__==2) && (__GNUC_MINOR__>=95)))
-#       undef wxUSE_WCHAR_T
-#       define wxUSE_WCHAR_T 0
-#   endif
-#endif
-
 #endif /* __GNUWIN32__ */
 
 /* MinGW32 doesn't provide wincred.h defining the API needed by this */
@@ -208,27 +214,6 @@
 #   endif
 #endif
 
-/*
-   Compiler-specific checks.
- */
-
-/* Borland */
-#ifdef __BORLANDC__
-
-#if __BORLANDC__ < 0x500
-    /* BC++ 4.0 can't compile JPEG library */
-#   undef wxUSE_LIBJPEG
-#   define wxUSE_LIBJPEG 0
-#endif
-
-/* wxUSE_DEBUG_NEW_ALWAYS = 1 not compatible with BC++ in DLL mode */
-#if defined(WXMAKINGDLL) || defined(WXUSINGDLL)
-#   undef wxUSE_DEBUG_NEW_ALWAYS
-#   define wxUSE_DEBUG_NEW_ALWAYS 0
-#endif
-
-#endif /* __BORLANDC__ */
-
 /*
    un/redefine the options which we can't compile (after checking that they're
    defined
@@ -250,6 +235,21 @@
 #   define wxUSE_ACTIVITYINDICATOR 0
 #endif /* !wxUSE_ACTIVITYINDICATOR && !_MSC_VER */
 
+/* MinGW-w64 (32 and 64 bit) has winhttp.h available, legacy MinGW does not. */
+#if (!defined(_MSC_VER) && !defined(__MINGW64_VERSION_MAJOR)) || !wxUSE_DYNLIB_CLASS
+    #undef wxUSE_WEBREQUEST_WINHTTP
+    #define wxUSE_WEBREQUEST_WINHTTP 0
+#endif
+/*
+    Similarly, turn off wxUSE_WEBREQUEST if we can't enable it because we don't
+    have any of its backends to allow the library to compile with the default
+    options when using MinGW32 which doesn't come with winhttp.h and so for
+    which we have to disable wxUSE_WEBREQUEST_WINHTTP.
+ */
+#if wxUSE_WEBREQUEST && !wxUSE_WEBREQUEST_CURL && !wxUSE_WEBREQUEST_WINHTTP
+#   undef wxUSE_WEBREQUEST
+#   define wxUSE_WEBREQUEST 0
+#endif /* wxUSE_WEBREQUEST */
 
 /* check settings consistency for MSW-specific ones */
 #if wxUSE_CRASHREPORT && !wxUSE_ON_FATAL_EXCEPTION
@@ -381,6 +381,15 @@
 #           define wxUSE_DRAG_AND_DROP 0
 #       endif
 #   endif
+
+#   if wxUSE_ACCESSIBILITY
+#       ifdef wxABORT_ON_CONFIG_ERROR
+#           error "wxUSE_ACCESSIBILITY requires wxUSE_OLE"
+#       else
+#           undef wxUSE_ACCESSIBILITY
+#           define wxUSE_ACCESSIBILITY 0
+#       endif
+#   endif
 #endif /* !wxUSE_OLE */
 
 #if !wxUSE_ACTIVEX
@@ -421,7 +430,7 @@
         and explicitly disabling wxUSE_DBGHELP (which would ideally result in
         an error if wxUSE_STACKWALKER is not disabled too), but it's better to
         avoid giving a compiler error in the former case even if it means not
-        giving it neither in the latter one.
+        giving it either in the latter one.
      */
     #undef wxUSE_STACKWALKER
     #define wxUSE_STACKWALKER 0
@@ -436,6 +445,14 @@
 #           define wxUSE_FSWATCHER 0
 #       endif
 #   endif
+#   if wxUSE_JOYSTICK
+#       ifdef wxABORT_ON_CONFIG_ERROR
+#           error "wxJoystick requires wxThread under MSW"
+#       else
+#           undef wxUSE_JOYSTICK
+#           define wxUSE_JOYSTICK 0
+#       endif
+#   endif
 #endif /* !wxUSE_THREADS */
 
 
@@ -455,4 +472,14 @@
 #   define wxUSE_POSTSCRIPT 1
 #endif
 
+/*
+    IPv6 support requires winsock2.h, but the default of wxUSE_WINSOCK2 is 0.
+    Don't require changing it explicitly and just turn it on automatically if
+    wxUSE_IPV6 is on.
+ */
+#if wxUSE_IPV6 && !wxUSE_WINSOCK2
+    #undef wxUSE_WINSOCK2
+    #define wxUSE_WINSOCK2 1
+#endif
+
 #endif /* _WX_MSW_CHKCONF_H_ */
