@@ -101,7 +101,7 @@ public:
 // ============================================================================
 
 /** @addtogroup group_funcmacro_file */
-//@{
+///@{
 
 /**
     A special return value of many wxWidgets classes to indicate that
@@ -129,26 +129,6 @@ typedef off_t wxFileOffset;
 */
 #define wxCHANGE_UMASK(mask)
 
-/**
-    This function returns the total number of bytes and number of free bytes on
-    the disk containing the directory @a path (it should exist). Both @a total
-    and @a free parameters may be @NULL if the corresponding information is not
-    needed.
-
-    @since 2.3.2
-
-    @note The generic Unix implementation depends on the system having the
-          @c statfs() or @c statvfs() function.
-
-    @return @true on success, @false if an error occurred (for example, the
-             directory doesn’t exist).
-
-    @header{wx/filefn.h}
-*/
-bool wxGetDiskSpace(const wxString& path,
-                    wxLongLong total = NULL,
-                    wxLongLong free = NULL);
-
 /**
     Returns the Windows directory under Windows; other platforms return an
     empty string.
@@ -252,6 +232,10 @@ time_t wxFileModificationTime(const wxString& filename);
     overwritten if @a overwrite is @true (default) and the function fails if @a
     overwrite is @false.
 
+    Since wxWidgets 3.2.7, if @a overwrite is @true `ReplaceFile()` function is
+    used under MSW which allows to preserve the file attributes while replacing
+    its contents.
+
     @header{wx/filefn.h}
 */
 bool wxRenameFile(const wxString& oldpath,
@@ -283,6 +267,9 @@ bool wxFileExists(const wxString& filename);
     @true, filenames beginning with a dot are not matched with wildcard
     characters.
 
+    @note Matching is always case-sensitive, even on platforms where paths
+          are generally treated as case-insensitive.
+
     @see wxIsWild()
 
     @header{wx/filefn.h}
@@ -370,7 +357,7 @@ bool wxRemoveFile(const wxString& file);
 enum wxPosixPermissions
 {
     /// Standard POSIX names for these permission flags with "wx" prefix.
-    //@{
+    ///@{
     wxS_IRUSR = 00400,
     wxS_IWUSR = 00200,
     wxS_IXUSR = 00100,
@@ -382,10 +369,10 @@ enum wxPosixPermissions
     wxS_IROTH = 00004,
     wxS_IWOTH = 00002,
     wxS_IXOTH = 00001,
-    //@}
+    ///@}
 
     /// Longer but more readable synonyms for the constants above.
-    //@{
+    ///@{
     wxPOSIX_USER_READ = wxS_IRUSR,
     wxPOSIX_USER_WRITE = wxS_IWUSR,
     wxPOSIX_USER_EXECUTE = wxS_IXUSR,
@@ -397,7 +384,7 @@ enum wxPosixPermissions
     wxPOSIX_OTHERS_READ = wxS_IROTH,
     wxPOSIX_OTHERS_WRITE = wxS_IWOTH,
     wxPOSIX_OTHERS_EXECUTE = wxS_IXOTH,
-    //@}
+    ///@}
 
     /// Default mode for the new files: allow reading/writing them to everybody but
     /// the effective file mode will be set after ANDing this value with umask and
@@ -507,10 +494,10 @@ enum wxFileKind
     wxFILE_KIND_PIPE      ///< A pipe
 };
 
-//@}
+///@}
 
 /** @addtogroup group_funcmacro_file */
-//@{
+///@{
 /**
     Returns the type of an open file. Possible return values are enumerations
     of ::wxFileKind.
@@ -519,10 +506,10 @@ enum wxFileKind
 */
 wxFileKind wxGetFileKind(int fd);
 wxFileKind wxGetFileKind(FILE* fp);
-//@}
+///@}
 
 /** @addtogroup group_funcmacro_file */
-//@{
+///@{
 /**
     @deprecated
         This function is obsolete, please use wxFileName::SplitPath() instead.
@@ -534,10 +521,10 @@ wxFileKind wxGetFileKind(FILE* fp);
 */
 wxString wxFileNameFromPath(const wxString& path);
 char* wxFileNameFromPath(char* path);
-//@}
+///@}
 
 /** @addtogroup group_funcmacro_file */
-//@{
+///@{
 /**
     @deprecated
         This function is obsolete, please use wxFileName::CreateTempFileName() instead.
@@ -546,5 +533,5 @@ char* wxFileNameFromPath(char* path);
 */
 char* wxGetTempFileName(const wxString& prefix, char* buf = NULL);
 bool wxGetTempFileName(const wxString& prefix, wxString& buf);
-//@}
+///@}
 
