@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     01.03.03
-// Copyright:   (c) 2003-2006 Vadim Zeitlin <vadim@wxwindows.org>
+// Copyright:   (c) 2003-2006 Vadim Zeitlin <vadim@wxwidgets.org>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -19,9 +19,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #ifndef WX_PRECOMP
     #include "wx/gdicmn.h"
@@ -77,6 +74,11 @@ wxIMPLEMENT_DYNAMIC_CLASS(wxDisplayModule, wxModule);
 // ctor/dtor
 // ----------------------------------------------------------------------------
 
+wxDisplay::wxDisplay()
+{
+    m_impl = Factory().GetPrimaryDisplay();
+}
+
 wxDisplay::wxDisplay(unsigned n)
 {
     wxASSERT_MSG( n == 0 || n < GetCount(),
@@ -89,7 +91,8 @@ wxDisplay::wxDisplay(const wxWindow* window)
 {
     const int n = GetFromWindow(window);
 
-    m_impl = Factory().GetDisplay(n != wxNOT_FOUND ? n : 0);
+    m_impl = n != wxNOT_FOUND ? Factory().GetDisplay(n)
+                              : Factory().GetPrimaryDisplay();
 }
 
 // ----------------------------------------------------------------------------
@@ -113,6 +116,11 @@ wxDisplay::wxDisplay(const wxWindow* window)
     return Factory().GetFromWindow(window);
 }
 
+/* static */ void wxDisplay::InvalidateCache()
+{
+    Factory().InvalidateCache();
+}
+
 // ----------------------------------------------------------------------------
 // functions forwarded to wxDisplayImpl
 // ----------------------------------------------------------------------------
@@ -138,6 +146,13 @@ wxSize wxDisplay::GetPPI() const
     return m_impl->GetPPI();
 }
 
+double wxDisplay::GetScaleFactor() const
+{
+    wxCHECK_MSG( IsOk(), 0, wxT("invalid wxDisplay object") );
+
+    return m_impl->GetScaleFactor();
+}
+
 int wxDisplay::GetDepth() const
 {
     wxCHECK_MSG( IsOk(), 0, wxT("invalid wxDisplay object") );
@@ -154,7 +169,7 @@ wxString wxDisplay::GetName() const
 
 bool wxDisplay::IsPrimary() const
 {
-    return m_impl && m_impl->GetIndex() == 0;
+    return m_impl && m_impl->IsPrimary();
 }
 
 #if wxUSE_DISPLAY
@@ -196,52 +211,50 @@ bool wxDisplay::ChangeMode(const wxVideoMode& mode)
     return *gs_factory;
 }
 
-// ============================================================================
-// wxDisplayImpl implementation
-// ============================================================================
-
-/* static */
-wxSize wxDisplayImpl::ComputePPI(int pxX, int pxY, int mmX, int mmY)
-{
-    if ( !mmX || !mmY )
-    {
-        // Physical size is unknown, return a special value indicating that we
-        // can't compute the resolution -- what else can we do?
-        return wxSize(0, 0);
-    }
-
-    return wxSize(wxRound((pxX * inches2mm) / mmX),
-                  wxRound((pxY * inches2mm) / mmY));
-}
-
-wxSize wxDisplayImpl::GetPPI() const
-{
-    const wxSize mm = GetSizeMM();
-
-    // We need physical pixels here, not logical ones returned by
-    // GetGeometry(), to compute the real DPI.
-    const wxSize pixels = GetGeometry().GetSize()*GetScaleFactor();
-
-    return ComputePPI(pixels.x, pixels.y, mm.x, mm.y);
-}
-
 // ============================================================================
 // wxDisplayFactory implementation
 // ============================================================================
 
-wxDisplayFactory::~wxDisplayFactory()
+void wxDisplayFactory::ClearImpls()
 {
     for ( size_t n = 0; n < m_impls.size(); ++n )
     {
         // It can be null, that's ok.
         delete m_impls[n];
     }
+
+    m_impls.clear();
+}
+
+wxDisplayImpl* wxDisplayFactory::GetPrimaryDisplay()
+{
+    // Just use dumb linear search -- there seems to be the most reliable way
+    // to do this in general. In particular, primary monitor is not guaranteed
+    // to be the first one and it's not obvious if it always contains (0, 0).
+    const unsigned count = GetCount();
+    for ( unsigned n = 0; n < count; ++n )
+    {
+        wxDisplayImpl* const d = GetDisplay(n);
+        if ( d && d->IsPrimary() )
+            return d;
+    }
+
+    // This is not supposed to happen, but what else can we do if it
+    // somehow does?
+    return NULL;
 }
 
 int wxDisplayFactory::GetFromWindow(const wxWindow *window)
 {
     wxCHECK_MSG( window, wxNOT_FOUND, "window can't be NULL" );
 
+    // Check if the window is created: we can't find its display before this is
+    // done anyhow, as we simply don't know on which display will it appear,
+    // and trying to do this below would just result in assert failures inside
+    // GetScreenRect() if the window doesn't yet exist, so return immediately.
+    if ( !window->GetHandle() )
+        return wxNOT_FOUND;
+
     // consider that the window belongs to the display containing its centre
     const wxRect r(window->GetScreenRect());
     return GetFromPoint(wxPoint(r.x + r.width/2, r.y + r.height/2));
