@@ -16,9 +16,6 @@
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #include "wx/defs.h"
 
@@ -84,8 +81,7 @@ bool wxGenericCollapsiblePane::Create(wxWindow *parent,
     m_pButton = new wxCollapsibleHeaderCtrl(this, wxID_ANY, label, wxPoint(0, 0),
                              wxDefaultSize);
 
-    // on other platforms we put the static line and the button horizontally
-    m_sz->Add(m_pButton, 0, wxLEFT|wxTOP|wxBOTTOM, GetBorder());
+    m_sz->Add(m_pButton, wxSizerFlags().Border(wxALL, GetBorder()));
 
     // FIXME: at least under wxGTK1 the background is black if we don't do
     //        this, no idea why...
@@ -112,7 +108,7 @@ wxGenericCollapsiblePane::~wxGenericCollapsiblePane()
     wxDELETE(m_sz);
 }
 
-wxSize wxGenericCollapsiblePane::DoGetBestSize() const
+wxSize wxGenericCollapsiblePane::DoGetBestClientSize() const
 {
     // NB: do not use GetSize() but rather GetMinSize()
     wxSize sz = m_sz->GetMinSize();
