@@ -1,5 +1,4 @@
-/* $Id$
- *
+/*
  * Project:  libtiff tools
  * Purpose:  Convert raw byte sequences in TIFF images
  * Author:   Andrey Kiselev, dron@ak4719.spb.edu
@@ -53,10 +52,22 @@
 # include <io.h>
 #endif
 
+#ifdef NEED_LIBPORT
+# include "libport.h"
+#endif
+
+#include "tiffiop.h"
 #include "tiffio.h"
 
+#ifndef EXIT_SUCCESS
+#define EXIT_SUCCESS 0
+#endif
+#ifndef EXIT_FAILURE
+#define EXIT_FAILURE 1
+#endif
+
 #ifndef HAVE_GETOPT
-extern int getopt(int, char**, char*);
+extern int getopt(int argc, char * const argv[], const char *optstring);
 #endif
 
 #ifndef O_BINARY
@@ -74,10 +85,10 @@ static	int quality = 75;		/* JPEG quality */
 static	uint16 predictor = 0;
 
 static void swapBytesInScanline(void *, uint32, TIFFDataType);
-static int guessSize(int, TIFFDataType, off_t, uint32, int,
+static int guessSize(int, TIFFDataType, _TIFF_off_t, uint32, int,
 		     uint32 *, uint32 *);
 static double correlation(void *, void *, uint32, TIFFDataType);
-static void usage(void);
+static void usage(int);
 static	int processCompressOptions(char*);
 
 int
@@ -85,7 +96,7 @@ main(int argc, char* argv[])
 {
 	uint32	width = 0, length = 0, linebytes, bufsize;
 	uint32	nbands = 1;		    /* number of bands in input image*/
-	off_t	hdr_size = 0;		    /* size of the header to skip */
+	_TIFF_off_t hdr_size = 0;	    /* size of the header to skip */
 	TIFFDataType dtype = TIFF_BYTE;
 	int16	depth = 1;		    /* bytes per pixel in input image */
 	int	swab = 0;		    /* byte swapping flag */
@@ -101,14 +112,16 @@ main(int argc, char* argv[])
 	uint32 row, col, band;
 	int	c;
 	unsigned char *buf = NULL, *buf1 = NULL;
+#if !HAVE_DECL_OPTARG
 	extern int optind;
 	extern char* optarg;
+#endif
 
 	while ((c = getopt(argc, argv, "c:r:H:w:l:b:d:LMp:si:o:h")) != -1) {
 		switch (c) {
 		case 'c':		/* compression scheme */
 			if (!processCompressOptions(optarg))
-				usage();
+				usage(EXIT_FAILURE);
 			break;
 		case 'r':		/* rows/strip */
 			rowsperstrip = atoi(optarg);
@@ -187,24 +200,24 @@ main(int argc, char* argv[])
 			outfilename = optarg;
 			break;
 		case 'h':
-			usage();
+			usage(EXIT_SUCCESS);
 		default:
 			break;
 		}
         }
 
         if (argc - optind < 2)
-		usage();
+		usage(EXIT_FAILURE);
 
         fd = open(argv[optind], O_RDONLY|O_BINARY, 0);
 	if (fd < 0) {
 		fprintf(stderr, "%s: %s: Cannot open input file.\n",
 			argv[0], argv[optind]);
-		return (-1);
+		return (EXIT_FAILURE);
 	}
 
 	if (guessSize(fd, dtype, hdr_size, nbands, swab, &width, &length) < 0)
-		return 1;
+		return EXIT_FAILURE;
 
 	if (outfilename == NULL)
 		outfilename = argv[optind+1];
@@ -212,7 +225,7 @@ main(int argc, char* argv[])
 	if (out == NULL) {
 		fprintf(stderr, "%s: %s: Cannot open file for output.\n",
 			argv[0], outfilename);
-		return (-1);
+		return (EXIT_FAILURE);
 	}
 	TIFFSetField(out, TIFFTAG_IMAGEWIDTH, width);
 	TIFFSetField(out, TIFFTAG_IMAGELENGTH, length);
@@ -277,20 +290,26 @@ main(int argc, char* argv[])
 	}
 	TIFFSetField(out, TIFFTAG_ROWSPERSTRIP, rowsperstrip );
 
-	lseek(fd, hdr_size, SEEK_SET);		/* Skip the file header */
+	_TIFF_lseek_f(fd, hdr_size, SEEK_SET);		/* Skip the file header */
 	for (row = 0; row < length; row++) {
 		switch(interleaving) {
 		case BAND:			/* band interleaved data */
 			for (band = 0; band < nbands; band++) {
-				lseek(fd,
-				      hdr_size + (length*band+row)*linebytes,
-				      SEEK_SET);
+				if (_TIFF_lseek_f(fd,
+                                          hdr_size + (length*band+row)*linebytes,
+                                          SEEK_SET) == (_TIFF_off_t)-1) {
+                                        fprintf(stderr,
+                                                "%s: %s: scanline %lu: seek error.\n",
+                                                argv[0], argv[optind],
+                                                (unsigned long) row);
+                                        break;
+                                }
 				if (read(fd, buf, linebytes) < 0) {
 					fprintf(stderr,
-					"%s: %s: scanline %lu: Read error.\n",
-					argv[0], argv[optind],
-					(unsigned long) row);
-				break;
+                                                "%s: %s: scanline %lu: Read error.\n",
+                                                argv[0], argv[optind],
+                                                (unsigned long) row);
+                                        break;
 				}
 				if (swab)	/* Swap bytes if needed */
 					swapBytesInScanline(buf, width, dtype);
@@ -324,7 +343,7 @@ main(int argc, char* argv[])
 	if (buf1)
 		_TIFFfree(buf1);
 	TIFFClose(out);
-	return (0);
+	return (EXIT_SUCCESS);
 }
 
 static void
@@ -352,17 +371,20 @@ swapBytesInScanline(void *buf, uint32 width, TIFFDataType dtype)
 }
 
 static int
-guessSize(int fd, TIFFDataType dtype, off_t hdr_size, uint32 nbands,
+guessSize(int fd, TIFFDataType dtype, _TIFF_off_t hdr_size, uint32 nbands,
 	  int swab, uint32 *width, uint32 *length)
 {
 	const float longt = 40.0;    /* maximum possible height/width ratio */
 	char	    *buf1, *buf2;
-	struct stat filestat;
+	_TIFF_stat_s filestat;
 	uint32	    w, h, scanlinesize, imagesize;
 	uint32	    depth = TIFFDataWidth(dtype);
-	float	    cor_coef = 0, tmp;
+	double	    cor_coef = 0, tmp;
 
-	fstat(fd, &filestat);
+	if (_TIFF_fstat_f(fd, &filestat) == -1) {
+                fprintf(stderr, "Failed to obtain file size.\n");
+		return -1;
+        }
 
 	if (filestat.st_size < hdr_size) {
 		fprintf(stderr, "Too large header size specified.\n");
@@ -390,43 +412,80 @@ guessSize(int fd, TIFFDataType dtype, off_t hdr_size, uint32 nbands,
 
 		return 1;
 	} else if (*width == 0 && *length == 0) {
+                unsigned int fail = 0;
 		fprintf(stderr,	"Image width and height are not specified.\n");
+                w = (uint32) sqrt(imagesize / longt);
+                if( w == 0 )
+                {
+                    fprintf(stderr, "Too small image size.\n");
+                    return -1;
+                }
 
-		for (w = (uint32) sqrt(imagesize / longt);
+		for (;
 		     w < sqrt(imagesize * longt);
 		     w++) {
 			if (imagesize % w == 0) {
 				scanlinesize = w * depth;
+				h = imagesize / w;
+				if (h < 2)
+					continue;
+				/* reads 2 lines at the middle of the image and calculate their correlation.
+				 * it works for h >= 2. (in this case it will compare line 0 and line 1 */
 				buf1 = _TIFFmalloc(scanlinesize);
 				buf2 = _TIFFmalloc(scanlinesize);
-				h = imagesize / w;
-				lseek(fd, hdr_size + (int)(h/2)*scanlinesize,
-				      SEEK_SET);
-				read(fd, buf1, scanlinesize);
-				read(fd, buf2, scanlinesize);
-				if (swab) {
-					swapBytesInScanline(buf1, w, dtype);
-					swapBytesInScanline(buf2, w, dtype);
-				}
-				tmp = (float) fabs(correlation(buf1, buf2,
-							       w, dtype));
-				if (tmp > cor_coef) {
-					cor_coef = tmp;
-					*width = w, *length = h;
-				}
+                                do {
+                                        if (_TIFF_lseek_f(fd, hdr_size + (int)((h - 1)/2)*scanlinesize,
+                                                  SEEK_SET) == (_TIFF_off_t)-1) {
+                                                fprintf(stderr, "seek error.\n");
+                                                fail=1;
+                                                break;
+                                        }
+                                        /* read line (h-1)/2 */
+                                        if (read(fd, buf1, scanlinesize) !=
+                                            (long) scanlinesize) {
+                                                fprintf(stderr, "read error.\n");
+                                                fail=1;
+                                                break;
+                                        }
+                                        /* read line ((h-1)/2)+1 */
+                                        if (read(fd, buf2, scanlinesize) !=
+                                            (long) scanlinesize) {
+                                                fprintf(stderr, "read error.\n");
+                                                fail=1;
+                                                break;
+                                        }
+                                        if (swab) {
+                                                swapBytesInScanline(buf1, w, dtype);
+                                                swapBytesInScanline(buf2, w, dtype);
+                                        }
+                                        if (0 == memcmp(buf1, buf2, scanlinesize)) {
+                                                *width = w, *length = h;
+                                        } else {
+                                                tmp = fabs(correlation(buf1, buf2,
+                                                                       w, dtype));
+                                                if (tmp > cor_coef) {
+                                                        cor_coef = tmp;
+                                                        *width = w, *length = h;
+                                                }
+                                        }
+                                } while (0);
 
-				_TIFFfree(buf1);
+                                _TIFFfree(buf1);
 				_TIFFfree(buf2);
 			}
 		}
 
+                if (fail) {
+                        return -1;
+                }
+
 		fprintf(stderr,
 			"Width is guessed as %lu, height is guessed as %lu.\n",
 			(unsigned long)*width, (unsigned long)*length);
 
 		return 1;
 	} else {
-		if (filestat.st_size<(off_t)(hdr_size+(*width)*(*length)*nbands*depth)) {
+		if (filestat.st_size<(_TIFF_off_t)(hdr_size+(*width)*(*length)*nbands*depth)) {
 			fprintf(stderr, "Input file too small.\n");
 		return -1;
 		}
@@ -522,6 +581,7 @@ correlation(void *buf1, void *buf2, uint32 n_elem, TIFFDataType dtype)
 	M2 /= n_elem;
 	D1 -= M1 * M1 * n_elem;
 	D2 -= M2 * M2 * n_elem;
+	if (D1 * D2 == 0.0) return 0.0;	/* avoid divide by zero */
 	K = (K - M1 * M2 * n_elem) / sqrt(D1 * D2);
 
 	return K;
@@ -545,7 +605,7 @@ processCompressOptions(char* opt)
                     else if (cp[1] == 'r' )
 			jpegcolormode = JPEGCOLORMODE_RAW;
                     else
-                        usage();
+                        usage(EXIT_FAILURE);
 
                     cp = strchr(cp+1,':');
                 }
@@ -564,7 +624,7 @@ processCompressOptions(char* opt)
 	return (1);
 }
 
-static char* stuff[] = {
+static const char* stuff[] = {
 "raw2tiff --- tool for converting raw byte sequences in TIFF images",
 "usage: raw2tiff [options] input.raw output.tif",
 "where options are:",
@@ -625,16 +685,22 @@ NULL
 };
 
 static void
-usage(void)
+usage(int code)
 {
-	char buf[BUFSIZ];
 	int i;
+	FILE * out = (code == EXIT_SUCCESS) ? stdout : stderr;
 
-	setbuf(stderr, buf);
-        fprintf(stderr, "%s\n\n", TIFFGetVersion());
+        fprintf(out, "%s\n\n", TIFFGetVersion());
 	for (i = 0; stuff[i] != NULL; i++)
-		fprintf(stderr, "%s\n", stuff[i]);
-	exit(-1);
+		fprintf(out, "%s\n", stuff[i]);
+	exit(code);
 }
 
 /* vim: set ts=8 sts=8 sw=8 noet: */
+/*
+ * Local Variables:
+ * mode: c
+ * c-basic-offset: 8
+ * fill-column: 78
+ * End:
+ */
