@@ -34,9 +34,14 @@
 #include "wx/vector.h"              // wxVector<wxString>
 
 #ifdef __WXGTK__
-    #include <gtk/gtk.h>
-    #include <gdk/gdkx.h>
-    #include "wx/gtk/private/gtk2-compat.h"
+    #include "wx/gtk/private/wrapgtk.h"
+    #include "wx/gtk/private/mediactrl.h"
+#endif
+
+#if GST_CHECK_VERSION(1,0,0)
+    typedef guintptr window_id_type;
+#else
+    typedef gulong window_id_type;
 #endif
 
 //-----------------------------------------------------------------------------
@@ -150,7 +155,12 @@ public:
     void HandleStateChange(GstState oldstate, GstState newstate);
     bool QueryVideoSizeFromElement(GstElement* element);
     bool QueryVideoSizeFromPad(GstPad* caps);
+
+    // SetupXOverlay() can only be called from the main thread, use
+    // CallSetupXOverlay() to call it from another thread.
     void SetupXOverlay();
+    void CallSetupXOverlay();
+
     bool SyncStateChange(GstElement* element, GstState state,
                          gint64 llTimeout = wxGSTREAMER_TIMEOUT);
     bool TryAudioSink(GstElement* audiosink);
@@ -205,11 +215,13 @@ class wxGStreamerMediaEventHandler : public wxEvtHandler
     public:
     wxGStreamerMediaEventHandler(wxGStreamerMediaBackend* be) : m_be(be)
     {
-        this->Connect(wxID_ANY, wxEVT_MEDIA_FINISHED,
-           wxMediaEventHandler(wxGStreamerMediaEventHandler::OnMediaFinish));
+        this->Bind(wxEVT_MEDIA_FINISHED,
+           &wxGStreamerMediaEventHandler::OnMediaFinish, this);
     }
 
     void OnMediaFinish(wxMediaEvent& event);
+    void NotifyMovieSizeChanged();
+    void NotifySetupXOverlay() { return m_be->SetupXOverlay(); }
 
     wxGStreamerMediaBackend* m_be;
 };
@@ -295,19 +307,12 @@ extern "C" {
 static gint gtk_window_realize_callback(GtkWidget* widget,
                                         wxGStreamerMediaBackend* be)
 {
-    gdk_flush();
-
-    GdkWindow* window = gtk_widget_get_window(widget);
-    wxASSERT(window);
+    window_id_type window_id = (window_id_type)wxGtkGetIdFromWidget(widget);
 
 #if GST_CHECK_VERSION(1,0,0)
-    gst_video_overlay_set_window_handle(be->m_xoverlay,
-                                GDK_WINDOW_XID(window)
-                                );
+    gst_video_overlay_set_window_handle(be->m_xoverlay, window_id);
 #else
-    gst_x_overlay_set_xwindow_id( GST_X_OVERLAY(be->m_xoverlay),
-                                GDK_WINDOW_XID(window)
-                                );
+    gst_x_overlay_set_xwindow_id( GST_X_OVERLAY(be->m_xoverlay), window_id);
 #endif
     GtkWidget* w = be->GetControl()->m_wxwindow;
 #ifdef __WXGTK3__
@@ -478,7 +483,7 @@ static GstBusSyncReply gst_bus_sync_callback(GstBus* bus,
     }
 
     wxLogTrace(wxTRACE_GStreamer, wxT("Got prepare-xwindow-id"));
-    be->SetupXOverlay();
+    be->CallSetupXOverlay();
     return GST_BUS_DROP; // We handled this message - drop from the queue
 }
 }
@@ -634,14 +639,14 @@ bool wxGStreamerMediaBackend::QueryVideoSizeFromPad(GstPad* pad)
         gst_caps_unref (caps);
 #endif
 
-        NotifyMovieSizeChanged ();
+        m_eventHandler->CallAfter(&wxGStreamerMediaEventHandler::NotifyMovieSizeChanged);
 
         return true;
     } // end if caps
 
     m_videoSize = wxSize(0,0);
 
-    NotifyMovieSizeChanged ();
+    m_eventHandler->CallAfter(&wxGStreamerMediaEventHandler::NotifyMovieSizeChanged);
 
     return false; // not ready/massive failure
 }
@@ -654,7 +659,10 @@ bool wxGStreamerMediaBackend::QueryVideoSizeFromPad(GstPad* pad)
 //-----------------------------------------------------------------------------
 void wxGStreamerMediaBackend::SetupXOverlay()
 {
+    wxASSERT( wxIsMainThread() );
+
     // Use the xoverlay extension to tell gstreamer to play in our window
+    window_id_type window_id;
 #ifdef __WXGTK__
     if (!gtk_widget_get_realized(m_ctrl->m_wxwindow))
     {
@@ -666,22 +674,17 @@ void wxGStreamerMediaBackend::SetupXOverlay()
     }
     else
     {
-        gdk_flush();
+        window_id = (window_id_type)wxGtkGetIdFromWidget(m_ctrl->m_wxwindow);
+#else
+        window_id = ctrl->GetHandle();
+#endif
 
-        GdkWindow* window = gtk_widget_get_window(m_ctrl->m_wxwindow);
-        wxASSERT(window);
-#endif
 #if GST_CHECK_VERSION(1,0,0)
-        gst_video_overlay_set_window_handle(m_xoverlay,
+        gst_video_overlay_set_window_handle(m_xoverlay, window_id);
 #else
-        gst_x_overlay_set_xwindow_id(GST_X_OVERLAY(m_xoverlay),
+        gst_x_overlay_set_xwindow_id(GST_X_OVERLAY(m_xoverlay), window_id);
 #endif
-#ifdef __WXGTK__
-                        GDK_WINDOW_XID(window)
-#else
-                        ctrl->GetHandle()
-#endif
-                                  );
+
 #ifdef __WXGTK__
         GtkWidget* w = m_ctrl->m_wxwindow;
 #ifdef __WXGTK3__
@@ -693,6 +696,11 @@ void wxGStreamerMediaBackend::SetupXOverlay()
 #endif
 }
 
+void wxGStreamerMediaBackend::CallSetupXOverlay()
+{
+    m_eventHandler->CallAfter(&wxGStreamerMediaEventHandler::NotifySetupXOverlay);
+}
+
 //-----------------------------------------------------------------------------
 // wxGStreamerMediaBackend::SyncStateChange
 //
@@ -826,6 +834,13 @@ bool wxGStreamerMediaBackend::TryVideoSink(GstElement* videosink)
         g_object_unref(videosink);
         return false;
     }
+
+    if ( gst_element_set_state (videosink,
+                                GST_STATE_READY) == GST_STATE_CHANGE_FAILURE )
+    {
+        g_object_unref(videosink);
+        return false;
+    }
 #else
     // Check if the video sink either is an xoverlay or might contain one...
     if( !GST_IS_BIN(videosink) && !GST_IS_X_OVERLAY(videosink) )
@@ -889,6 +904,11 @@ void wxGStreamerMediaEventHandler::OnMediaFinish(wxMediaEvent& WXUNUSED(event))
     }
 }
 
+void wxGStreamerMediaEventHandler::NotifyMovieSizeChanged()
+{
+    m_be->NotifyMovieSizeChanged();
+}
+
 //-----------------------------------------------------------------------------
 //
 // Public methods
@@ -1044,7 +1064,7 @@ bool wxGStreamerMediaBackend::CreateControl(wxControl* ctrl, wxWindow* parent,
 
     // don't erase the background of our control window
     // so that resizing is a bit smoother
-    m_ctrl->SetBackgroundStyle(wxBG_STYLE_CUSTOM);
+    m_ctrl->SetBackgroundStyle(wxBG_STYLE_PAINT);
 
     // Create our playbin object
     m_playbin = gst_element_factory_make ("playbin", "play");
