@@ -12,41 +12,17 @@
 
 #include "testprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
 
 #ifndef WX_PRECOMP
     #include "wx/event.h"
+    #include "wx/timer.h"
 #endif // WX_PRECOMP
 
-// --------------------------------------------------------------------------
-// test class
-// --------------------------------------------------------------------------
-
-class EventCloneTestCase : public CppUnit::TestCase
+TEST_CASE("EventClone", "[wxEvent][clone]")
 {
-public:
-    EventCloneTestCase() {}
+    // Dummy timer needed just to create a wxTimerEvent.
+    wxTimer dummyTimer;
 
-private:
-    CPPUNIT_TEST_SUITE( EventCloneTestCase );
-        CPPUNIT_TEST( CheckAll );
-    CPPUNIT_TEST_SUITE_END();
-
-    void CheckAll();
-
-    DECLARE_NO_COPY_CLASS(EventCloneTestCase)
-};
-
-// register in the unnamed registry so that these tests are run by default
-CPPUNIT_TEST_SUITE_REGISTRATION( EventCloneTestCase );
-
-// also include in its own registry so that these tests can be run alone
-CPPUNIT_TEST_SUITE_NAMED_REGISTRATION( EventCloneTestCase, "EventCloneTestCase" );
-
-void EventCloneTestCase::CheckAll()
-{
     // check if event classes implement Clone() correctly
     // NOTE: the check is done against _all_ event classes which are linked to
     //       the executable currently running, which are not necessarily all
@@ -55,26 +31,36 @@ void EventCloneTestCase::CheckAll()
     for (; ci; ci = ci->GetNext())
     {
         wxString cn = wxString(ci->GetClassName());
-    
+
         // is this class derived from wxEvent?
         if ( !ci->IsKindOf(CLASSINFO(wxEvent)) ||
              cn == "wxEvent" )
             continue;
 
-        const std::string
-            msg = std::string("Event class \"") + 
-                  std::string(cn.c_str()) + "\"";
+        INFO("Event class \"" << cn << "\"");
 
-        CPPUNIT_ASSERT_MESSAGE( msg, ci->IsDynamic() );
+        wxEvent* test;
+        if ( ci->IsDynamic() )
+        {
+            test = wxDynamicCast(ci->CreateObject(),wxEvent);
+        }
+        else if ( cn == "wxTimerEvent" )
+        {
+            test = new wxTimerEvent(dummyTimer);
+        }
+        else
+        {
+            FAIL("Can't create objects of type " + cn);
+            continue;
+        }
 
-        wxEvent * const test = wxDynamicCast(ci->CreateObject(),wxEvent);
-        CPPUNIT_ASSERT_MESSAGE( msg, test );
+        REQUIRE( test );
 
         wxEvent * const cloned = test->Clone();
         delete test;
 
-        CPPUNIT_ASSERT_MESSAGE( msg, cloned );
-        CPPUNIT_ASSERT_MESSAGE( msg, cloned->GetClassInfo() == ci );
+        REQUIRE( cloned );
+        CHECK( cloned->GetClassInfo() == ci );
 
         delete cloned;
     }
